# AUTOGENERATED! DO NOT EDIT! File to edit: pcts/submodule/utils.pct.py

__all__ = ['greet_multiple', 'sum_list']

# %% pcts/submodule/utils.pct.py 2
from ..core import greet, add

# %% pcts/submodule/utils.pct.py 3
def greet_multiple(names: list[str]) -> list[str]:
    """Greet multiple people.
    
    Args:
        names: List of names to greet.
        
    Returns:
        List of greeting strings.
    """
    return [greet(name) for name in names]

# %% pcts/submodule/utils.pct.py 5
def sum_list(numbers: list[int]) -> int:
    """Sum a list of numbers using the add function.
    
    Args:
        numbers: List of integers to sum.
        
    Returns:
        Sum of all numbers.
    """
    result = 0
    for num in numbers:
        result = add(result, num)
    return result
